#
# spec file for package smartmontools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif
Name:           smartmontools
Version:        7.4
Release:        2.5
Summary:        Monitor for SMART devices
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://www.smartmontools.org/
Source:         https://sourceforge.net/projects/smartmontools/files/smartmontools/%{version}/%{name}-%{version}.tar.gz
Source1:        https://sourceforge.net/projects/smartmontools/files/smartmontools/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        smartmontools.sysconfig
Source3:        %{name}-rpmlintrc
Source4:        %{name}.keyring
# SOURCE-FEATURE-OPENSUSE smartmontools.generate_smartd_opts.in sbrabec@suse.cz -- sysconfig support for systemd.
Source5:        %{name}.generate_smartd_opts.in
# SOURCE-FEATURE-SLE smartmontools-drivedb_h-update.sh bnc851276 sbrabec@suse.cz -- Supplementary script to update drivedb.h.
Source6:        smartmontools-drivedb_h-update.sh
# SOURCE-FEATURE-UPSTREAM smartmontools-drivedb.h bnc851276 sbrabec@suse.cz -- Update of drivedb.h. (Following line is handled by smartmontools-drivedb_h-update.sh.)
#Source7:        smartmontools-drivedb.h
Source8:        smartd_generate_opts.path
Source9:        smartd_generate_opts.service
# PATCH-FEATURE-OPENSUSE smartmontools-suse-default.patch sbrabec@suse.cz -- Define smart SUSE defaults.
Patch4:         smartmontools-suse-default.patch
# PATCH-FIX-OPENSUSE smartmontools-var-lock-subsys.patch sbrabec@suse.cz -- Do not use unsupported /var/lock/subsys.
Patch10:        smartmontools-var-lock-subsys.patch
# PATCH-FIX-SLE smartd_service_dont_quit.patch bsc990406 bsc1167051 msuchanek@suse.de -- Do not quit when no drives are available.
Patch11:        smartd_service_dont_quit.patch
Patch12:        harden_smartd.service.patch
BuildRequires:  gcc-c++
BuildRequires:  libcap-ng-devel
BuildRequires:  libselinux-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
Requires(pre):  %fillup_prereq
# Needed by generate_smartd_opt:
Requires(pre):  coreutils
%{?systemd_requires}

%description
SMARTmontools controls and monitors storage devices using the
Self-Monitoring, Analysis, and Reporting Technology System (S.M.A.R.T.)
built into ATA, SATA and SCSI Hard Drives. This is used to check the
hard drive reliability and to predict drive failures. The suite
contains two utilities. The first, smartctl, is a command line utility
designed to perform simple S.M.A.R.T. tasks. The second, smartd, is a
daemon that periodically monitors the smart status and reports errors
to syslog. The package is compatible with the ATA/ATAPI-3 to -7
specification. The package is intended to incorporate as much "vendor
specific" and "reserved" information as possible about disk drives. The
commands man smartctl and man smartd will provide more information.

%prep
%autosetup -p1
cp -a %{SOURCE2} %{SOURCE5} .
# Following line is handled by smartmontools-drivedb_h-update.sh.
#cp -a %{SOURCE7} drivedb.h.new
#
# PATCH-FEATURE-OPENSUSE (sed on smartd.service.in) sbrabec@suse.cz -- Use generated smartd_opts (from SUSE sysconfig file). Systemd smartd.service cannot be smart enough to parse SUSE sysconfig file and generate smartd_opts on fly. And we do not want to launch shell just for it in every boot.
sed "s:/usr/local/etc/sysconfig/smartmontools:%{_localstatedir}/lib/smartmontools/smartd_opts:" <smartd.service.in >smartd.service.in.new
if cmp -s smartd.service.in smartd.service.in.new ; then
	echo "Failed to modify smartd.service.in"
	exit 1
fi
mv smartd.service.in.new smartd.service.in
#
# Check whether drivedb.h from the tarball is older than drivedb.h.new
# If yes, replace it. If not, fail.
# PACKAGERS: Don't delete this section. It prevents packaging of outdated smartmontools-drivedb.h.
if test -f drivedb.h.new ; then
	UPD_TIME=$(date -d "$(sed -n 's/^.*$Id: drivedb.h [0-9][0-9]* \([^ ]* [^ ]*\) .*$/\1/p' <drivedb.h.new)" +%s)
	PCK_TIME=$(date -d "$(sed -n 's/^.*$Id: drivedb.h [0-9][0-9]* \([^ ]* [^ ]*\) .*$/\1/p' <drivedb.h)" +%s)
	if test $UPD_TIME -lt $PCK_TIME ; then
		echo >&2 "Packaging error: Attached smartmontools-drivedb.h is older than the one from the release.
		  Please call \"bash ./smartmontools-drivedb_h-update.sh\" to fix it."
		exit 1
	fi
	mv drivedb.h.new drivedb.h
fi

%build
export CFLAGS="%{optflags} $(getconf LFS_CFLAGS) -fPIE"
export CXXFLAGS="%{optflags} -fPIE $(getconf LFS_CFLAGS)"
export LDFLAGS="-pie"
%configure\
	--docdir=%{_defaultdocdir}/%{name}\
	--with-selinux\
	--with-libsystemd\
	--with-systemdsystemunitdir=%{_unitdir}\
	--with-savestates \
	--with-attributelog \
	--with-nvme-devicescan

%make_build BUILD_INFO='"(SUSE RPM)"'
SERVICE=%{_sbindir}/service
sed "s:@prefix@:%{_prefix}:g;s:@localstatedir@:%{_localstatedir}:g;s:@SERVICE@:$SERVICE:" <smartmontools.generate_smartd_opts.in >generate_smartd_opts

%install
%make_install
mkdir -p %{buildroot}%{_prefix}/lib/smartmontools
mkdir -p %{buildroot}%{_fillupdir}
cp smartmontools.sysconfig %{buildroot}%{_fillupdir}/sysconfig.smartmontools
mkdir -p %{buildroot}%{_localstatedir}/lib/smartmontools
touch %{buildroot}%{_localstatedir}/lib/smartmontools/smartd_opts
install generate_smartd_opts %{buildroot}%{_prefix}/lib/smartmontools/
cat >%{buildroot}%{_sysconfdir}/smart_drivedb.h <<EOF
/* smart_drivedb.h: Custom drive database. See also %{_datadir}/smartmontools/drivedb.h. */
EOF
cp smartd.service %{buildroot}/%{_unitdir}
cp %{SOURCE8} %{buildroot}/%{_unitdir}
cp %{SOURCE9} %{buildroot}/%{_unitdir}
ln -sf %{_sbindir}/service  %{buildroot}%{_sbindir}/rcsmartd
# INSTALL file is intended only for packagers.
rm %{buildroot}%{_defaultdocdir}/%{name}/INSTALL
# Create empty ghost files for files created by update-smart-drivedb.
touch %{buildroot}%{_datadir}/smartmontools/drivedb.h.{error,lastcheck,old}

# Check syntax of drivedb.h that may come from a later snapshot (code from update-smart-drivedb)
if ./smartctl -B drivedb.h -P showall >/dev/null; then :; else
  echo "drivedb.h.error: rejected by smartctl, probably no longer compatible" >&2
  exit 1
fi
# Intelligent drivedb.h update, part 0.
# Check that drivedb.h has well formed svn RELEASE. We will need it for the intelligent update.
DRIVEDB_H_RELEASE_CHECK="$(sed -n 's/^.*$Id: drivedb.h \([0-9][0-9]*\) .*$/\1/p' <%{buildroot}%{_datadir}/smartmontools/drivedb.h)"
# Fail if the file has broken release number.
test "$DRIVEDB_H_RELEASE_CHECK" -ge 0
# Fail if there is no default_branch= in update-smart-drivedb
grep -q "^default_branch=\"[^\"]*\"$" update-smart-drivedb

%pre
%service_add_pre smartd.service smartd_generate_opts.path smartd_generate_opts.service
# Intelligent drivedb.h update, part 1.
# Extract drivedb.h branch for installed version. We will need it in %%post.
if test -f %{_sbindir}/update-smart-drivedb ; then
    BRANCH=
    eval $(grep "^BRANCH=\"[^\"]*\"$" %{_sbindir}/update-smart-drivedb)
    if test -n "$BRANCH" ; then
	echo -n "$BRANCH" >%{_datadir}/smartmontools/drivedb.h.branch.rpmtemp
    fi
fi
# Save installed drivedb.h. Maybe the sysadmin called update-smart-drivedb,
# and the installed drivedb.h may be even newer than the new packaged one.
if test -f %{_datadir}/smartmontools/drivedb.h ; then
    # Be on safe side, remove any potential drivedb.h.rpmsave.
    rm -f %{_datadir}/smartmontools/drivedb.h.rpmsave
    ln %{_datadir}/smartmontools/drivedb.h %{_datadir}/smartmontools/drivedb.h.rpmsave
fi

%post
# First prepare sysconfig.
%fillup_only
# Up to Leap 42.3 and SLE 15 SP3 Maintenance Update there was a "Command" meta comment in the sysconfig file.
# It is not needed any more, but fillup does not delete it. Do it explicitly. (bsc#1195785, bsc#1196103)
sed -i '\@^##[[:space:]]*Command:[[:space:]]*%{_prefix}/lib/smartmontools/generate_smartd_opts$@d' %{_sysconfdir}/sysconfig/smartmontools
# Then generate initial %%{_localstatedir}/lib/smartmontools/smartd_opts needed by smartd.service.
SMARTD_SKIP_INIT=1 %{_prefix}/lib/smartmontools/generate_smartd_opts
# No start by default here.. belongs to -presets packages
%service_add_post smartd.service smartd_generate_opts.path smartd_generate_opts.service
# Intelligent drivedb.h update, part 2.
# Now we have the old system drivedb.h.rpmsave and the new packaged drivedb.h.
if test -f %{_datadir}/smartmontools/drivedb.h.rpmsave ; then
    # Compare their release numbers.
    DRIVEDB_H_RELEASE_RPM="$(sed -n 's/^.*$Id: drivedb.h \([0-9][0-9]*\) .*$/\1/p' <%{_datadir}/smartmontools/drivedb.h)"
    DRIVEDB_H_RELEASE_SAVED="$(sed -n 's/^.*$Id: drivedb.h \([0-9][0-9]*\) .*$/\1/p' <%{_datadir}/smartmontools/drivedb.h.rpmsave)"
    # Note: The SAVED release number may be broken. The test syntax must cover it and replace old file.
    if test "$DRIVEDB_H_RELEASE_RPM" -lt "${DRIVEDB_H_RELEASE_SAVED:-0}" ; then
	# If it is an update to the new branch, always replace the database.
	# Extract drivedb.h branch for the new version to default_branch.
	eval $(grep "^default_branch=\"[^\"]*\"$" %{_sbindir}/update-smart-drivedb)
	OLD_BRANCH=
	if test -f %{_datadir}/smartmontools/drivedb.h.branch.rpmtemp ; then
	    OLD_BRANCH=$(<%{_datadir}/smartmontools/drivedb.h.branch.rpmtemp)
	fi
	if test "$default_branch" = "$OLD_BRANCH" ; then
	    # It is safe to keep later version of installed database.
	    mv %{_datadir}/smartmontools/drivedb.h.rpmsave %{_datadir}/smartmontools/drivedb.h
	else
	    # Saved file needs to be replaced.
	    rm %{_datadir}/smartmontools/drivedb.h.rpmsave
	    # We returned to the vanilla packages, remove files created by update-smart-drivedb.
	    rm -f %{_datadir}/smartmontools/drivedb.h.{error,lastcheck,old}
	    echo >&2 "%{name} updated to a version that requires new branch of drivedb.h"
	    echo >&2 "Replacing your custom drivedb.h."
	    echo >&2 "You may need to call update-smart-drivedb."
	fi
    else
	# Saved file is older or equal, or saved file has broken release number.
	rm %{_datadir}/smartmontools/drivedb.h.rpmsave
	# We returned to the vanilla packages, remove files created by update-smart-drivedb.
	rm -f %{_datadir}/smartmontools/drivedb.h.{error,lastcheck,old}
    fi
fi
rm -f %{_datadir}/smartmontools/drivedb.h.branch.rpmtemp
# Before Leap 15 / SLE 15, there was a incorrect configuration of self tests (bsc#1073918).
# Perform a fix of this nonsense, even if the noreplace configuration file was edited.
if grep -q -F -- '-s S/../.././03 -s L/../(01|02|03|04|05|06|07)/7/01' %{_sysconfdir}/smartd.conf ; then
	sed -i 's:-s S/\.\./\.\./\./03 -s L/\.\./(01|02|03|04|05|06|07)/7/01:-s (S/../.././03|L/../(01|02|03|04|05|06|07)/7/01):g' %{_sysconfdir}/smartd.conf
fi

%preun
%service_del_preun smartd.service smartd_generate_opts.path smartd_generate_opts.service

%postun
%service_del_postun smartd.service smartd_generate_opts.path smartd_generate_opts.service
# Clean all attrlogs and state files.
if test "$1" = 0 ; then
    rm -rf %{_localstatedir}/lib/smartmontools
fi

%files
%doc %{_docdir}/%{name}
%dir %{_datadir}/smartmontools
%verify(not md5 size mtime) %{_datadir}/smartmontools/drivedb.h
%ghost %{_datadir}/smartmontools/drivedb.h.error
%ghost %{_datadir}/smartmontools/drivedb.h.lastcheck
%ghost %{_datadir}/smartmontools/drivedb.h.old
%{_mandir}/man*/*
%dir %{_localstatedir}/lib/smartmontools
%ghost %{_localstatedir}/lib/smartmontools/smartd_opts
%{_prefix}/lib/smartmontools
%{_unitdir}/*
%{_sbindir}/*
%config(noreplace) %{_sysconfdir}/smart_drivedb.h
%config(noreplace) %{_sysconfdir}/smartd.conf
%config(noreplace) %{_sysconfdir}/smartd_warning.sh
%config %dir %{_sysconfdir}/smartd_warning.d
%{_fillupdir}/sysconfig.*

%changelog
* Fri Sep 22 2023 Michal Suchanek <msuchanek@suse.com>
- Do not quit with an error when no drives to monitor are available (bsc#990406 bsc#1167051).
- Add smartd_service_dont_quit.patch
- Refresh harden_smartd.service.patch
- Run through spec-cleaner, use autosetup
* Wed Aug  9 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to version 7.4:
  * See NEWS and ChangeLog files for full details
- Drop smartmontools-smartctl-NVMe-big-endian.patch (upstreamed)
- Refresh smartmontools-suse-default.patch
* Thu Jul 13 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- smartmontools.generate_smartd_opts.in: Fix generated options when
  SMARTD_SAVESTATES or SMARTD_ATTRLOG are set to "no" (bsc#1207461).
* Tue Mar  7 2023 pgajdos@suse.com
- fix smartctl crash for an NVMe on big endian systems [bsc#1208905]
- added patches
  fix https://www.smartmontools.org/changeset/5448
  + smartmontools-smartctl-NVMe-big-endian.patch
* Thu Feb  2 2023 Hans-Peter Jansen <hpj@urpla.net>
- Catch another invalid state in %%post: DRIVEDB_H_RELEASE_SAVED
  might end up empty
* Thu Apr 21 2022 Dirk Müller <dmueller@suse.com>
- refresh keyring with new signing key
* Fri Apr 15 2022 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 7.3
  - see NEWS and ChangeLog file for full details
- Remove smartmontools-drivedb.h. Up to date version is included
  in release tarball
- packaging: try to fix smartmontools-drivedb_h-update.sh
* Thu Feb 17 2022 Stanislav Brabec <sbrabec@suse.com>
- Restart smartd and generate smartd_opts only if there are real
  sysconfig changes; do not trigger generate_smartd_opts by YaST,
  systemd is enough (bsc#1195785).
* Mon Nov 29 2021 Stanislav Brabec <sbrabec@suse.com>
- Update smartmontools-drivedb.h to the latest version from the
  upstream branch RELEASE_7_2_DRIVEDB.
* Wed Nov 17 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_smartd.service.patch
  Modified:
  * smartd_generate_opts.service
* Tue Aug 24 2021 Stanislav Brabec <sbrabec@suse.com>
- smartmontools-drivedb_h-update.sh: Fix update needed logic.
- Add smartmontools-drivedb.h, the latest version from the upstream
  branch RELEASE_7_2_DRIVEDB.
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 7.2:
  - smartctl: New option '--json=y[c]' selects YAML output.
  - smartctl '-i': Prints ATA TRIM and Zoned Device capabilities.
  - smartctl '-j': Fixed 'scsi_grown_defect_list' value.
  - smartctl '-a': Prints SCSI 'Accumulated power on time'.
  - smartctl '-n POWERMODE': SCSI support.
  - smartctl '-s standby,now' and '-s standby,off': SCSI support.
  - smartctl '-c': NVMe 1.4 additions.
  - smartd: Support for staggered self-tests.
  - smartd: No longer writes attribute log if no attributes were read
    due to standby mode or other error.
  - smartd: Now resolves symlinks before device names are checked for
    duplicates.
  - smartd: Fixed SMARTD_DEVICETYPE environment variable if DEVICESCAN is
    used without '-d TYPE'.
  - ATA: Device type '-d jmb39x-q,N' for JMB39x protocol variant used by
    some QNAP NAS devices.
  - ATA: Device type '-d jms56x,N' for JMS562 USB to SATA RAID bridges.
  - SCSI: Improved heuristics for log subpages of new and very old disks.
  - NVMe: Log transfer size limited to avoid device or kernel crashes.
  - NVMEe/USB: Device type '-d sntrealtek' for Realtek RTL9210 USB to
    NVMe bridges.
  - update-smart-drivedb: New option '--branch X.Y'.
  - HDD, SSD and USB additions to drive database.
  - Dropped support for pre-C99 snprintf().
  - configure: Dropped option '--without-working-snprintf'.
  - configure: Fixed '-fstack-protector*' detection.
  - Linux: Various fixes of smartd.service file (bsc#1183699).
  - Darwin: NVMe log support.
  - FreeBSD: Device scan does no longer include T_ENCLOSURE devices.
  - NetBSD: Fixed timeout handling.
  - NetBSD big endian: Fixed ATA register handling.
  - OpenBSD: Fixed timeout handling.
  - Windows: Dropped backward compatibility fixes for very old compilers.
- drop smartd-service-novm.patch (upstream)
- drop smartmontools-smartd-service.patch
  (SLE+Leap, now in upstream, bsc#1183699)
* Sat Jan  4 2020 Stanislav Brabec <sbrabec@suse.com>
- Update to version 7.1:
  * smartctl: Fixed bogus exception on unknown form factor value.
  * smartctl '--json=cg': Suppresses extra spaces also in 'g'
    format.
  * smartctl '-i': ATA ACS-4 and ACS-5 enhancements.
  * smartd: No longer truncates very long device names in warning
    emails.
  * smartd: No longer skips scheduled tests if system clock has
    been adjusted to the past.
  * smartd '-A': Attribute logs now use local time instead of UTC.
  * ATA: Device type '-d jmb39x,N' for drives behind JMicron JMB39x
    RAID port multipliers.
  * SCSI: Workaround for incomplete Log subpages response from some
    SAS SSDs.
  * HDD, SSD and USB additions to drive database.
  * Autodetection of '-d sntjmicron' type for JMicron USB to NVMe
    bridges.
  * Fixed segfault on CCISS transfer sizes > 512 bytes.
  * Fixed smartd.service 'Type' if libsystemd-dev is not available.
  * Fixed '/dev/megaraid_sas_ioctl_node' fd leak.
  * Fixed GPL licensing problem of 'linux_nvme_ioctl.h'
    (smartmontools#1226,
    drop smartmontools-nvme_ioctl_h-license.patch).
- Update smartmontools.keyring. Developers use new key.
- smartmontools-drivedb_h-update.sh: Recognize equal files in
  different commits.
- Drop smartmontools-nvme_ioctl_h-license.patch (SLE+Leap,
  now in upstream, https://www.smartmontools.org/ticket/1226)
- Remove smartmontools-drivedb.h. No update available in the
  upstream branch RELEASE_7_0_DRIVEDB.
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Tue Aug  6 2019 sbrabec@suse.com
- Fix license of nvme_ioctl.h
  (https://www.smartmontools.org/ticket/1226,
  smartmontools-nvme_ioctl_h-license.patch).
* Tue Jun  4 2019 rw@suse.com
- Update to 7.0 version
  - smartctl
  * New options '-j' and '--json[=giosu]' to enable experimental
    JSON output mode.  Also supports an alternative flat format
    suitable for grep ('--json=g').
  * '-l devstat': Fix for logs with 256 sectors.
  * '-l error': Prints SCSI Pending Defects log page if supported.
  * '-H': Prints SCSI Format Status log page if supported.
  * '-x': Now includes '-l defects'.
  * New option '-d scsi+TYPE' to disable SAT auto detection for
    'aacraid' and 'cciss'.
  - NVMe/USB: Device type '-d sntjmicron' for NVMe drives behind
    JMicron USB to NVMe bridges.
  - NVMe: SMART/Health Information and Error Information are always
    read with broadcast NSID.
  - SCSI: Various improvements for the decoding of log pages.
  - SCSI: Improved handling of READ CAPACITY command.
  - SCSI: Support for SAS host managed drives.
  - update-smart-drivedb: New option '-u github'.
  - update-smart-drivedb: New signing key.
  - HDD, SSD and USB additions to drive database.
  - Always use '-d sat' for USB vendor IDs with known SAT support.
  - Linux
  * Device scan with '-d by-id' scans '/dev/disk/by-id/*' symlinks.
  * Dropped device scan support for devfs.
  * Fixed device scan with multiple '-d TYPE' options.
  * Fixed device scan crash on missing '/proc/devices'.
  * USB ID detection also for '/dev/sgN'.
  * smartd: Could now run as systemd service with 'Type=notify' set.
- Drop upstreamed patches:
  * smartmontools-scsiata-scsi_only.patch
  * smartmontools-systemd-no-syslog.patch
- Update smartmontools-drivedb.h to the latest version from the
  upstream branch RELEASE_7_0_DRIVEDB.
* Tue Sep 25 2018 sbrabec@suse.com
- Fix smartd.service EnvironmentFile (boo#1095662).
* Fri Jun 22 2018 kukuk@suse.de
- Add smartd_generate_opts.path and smartd_generate_opts.service
  to update smartd_opts if sysconfig is modified. Needed for
  [FATE#325524].
* Tue Apr 17 2018 sbrabec@suse.com
- Fix SUSE default of S.M.A.R.T. checks: really enable nightly
  short tests (bsc#1073918).
* Thu Feb  8 2018 sbrabec@suse.com
- Make possible to disable broken SAT support by -d scsi+cciss,N
  (bsc#1038271, smartmontools-scsiata-scsi_only.patch,
  https://www.smartmontools.org/ticket/871).
- Update smartmontools.keyring.
* Mon Dec 18 2017 avindra@opensuse.org
- update to 6.6 version (FATE#321901, FATE#322874)
  - smartctl:
  * -i' and '--identify': ATA ACS-4 and SATA 3.3 enhancements.
  * Control ATA write cache through SCT Feature Control
    with '-s wcache-sct,ata|on|off[,p]' and '-g wcache-sct'.
  * Print ATA Pending Defects log with '-l defects'.
  * '-s wcreorder,on|off': New persistent flag ',p'.
  * '-s standby': Prevent temporary drive spinup.
  * '-n POWERMODE': New parameter to set exit status.
  * '-g security': ATA Security Level check fixed.
  * '-l scttemp*': Print minimum supported ERC Time Limit.
  * '-q noserial': Now also suppresses "SAS address" output.
  * '-i': Print IEEE EUI-64 of NVMe namespace.
  * '-c': Print NVMe 1.3 feature flags.
  * '-A': Print NVMe 1.3 thermal temperature transition
    statistic.
  * '-g/s dsn': Get/set ATA DSN.
  - smartd
  * Uses also device identify information to detect for duplicate
    devices.
  * '-e dsn' directive: Set ATA DSN.
  * Improved SCSI/SAS temperature logging.
  * Silence emails and log messages on open errors of
    '-d removable' devices.
  * Exit on device open error unless '-q never' or '-d removable'
    is specified (regression).
  - update-smart-drivedb: Now authenticates downloaded file with GnuPG.
  - update-smart-drivedb: New options '--trunk', '--no-verify' and
    '--export-key'.
  - Device type '-d intelliprop,N' for IntelliProp controllers.
  - SCSI: Default timeout increased to 1 minute.
  - HDD, SSD and USB additions to drive database.
  - New smartmontools-* mailing list addresses.
  - Man page formatting reworked.
  - Linux:
  * Uses SG_IO V4 API if supported.
  * Devices behind hpsa driver are no longer detected as regular
    SCSI devices.
- switch to new url
- drop upstreamed patches:
  * smartmontools-scsi-suppress-no-temperature.patch
  * smartmontools-scsi-temperature-check.patch
  * smartmontools-log-scsi-temperature.patch
- regen smartmontools-drivedb.h
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Jul 14 2017 sbrabec@suse.com
- SCSI temperature error fixes (bsc#1047198,
  smartmontools-scsi-suppress-no-temperature.patch,
  smartmontools-scsi-temperature-check.patch,
  smartmontools-log-scsi-temperature.patch).
* Mon Dec 19 2016 sbrabec@suse.com
- Drop systemd dependency on syslog.target (bsc#983938,
  smartmontools-systemd-no-syslog.patch).
  https://lists.opensuse.org/opensuse-packaging/2013-05/msg00102.html
* Wed Dec  7 2016 aginies@suse.com
- update to 6.5 version
  * Experimental support for NVMe devices on FreeBSD, Linux and Windows.
  * smartctl '-i', '-c', '-H' and '-l error': NVMe support.
  * smartctl '-l nvmelog': New option for NVMe.
  * smartd.conf '-H', '-l error' and '-W': NVMe support.
  * Optional NVMe device scanning support on Linux and Windows.
  * configure option '--with-nvme-devicescan' to include NVMe in
    default device scanning result.
  * Device scanning now allows to specify multiple '-d TYPE' options.
  * ATA: Added new POWER MODE values introduced in ATA ACS-2.
  * ATA: SCT commands are no longer issued if ATA Security is locked.
  * SCSI: LB provisioning improvements.
  * SCSI: Fixed GLTSD bit set/cleared info messages.
  * SCSI: Solid State media log page is no longer checked for tapes.
  * SCSI: Improved handling when no tape cartridge in drive.
  * SCSI: Workaround for buggy Seagate firmware.
  * SAT: Improved heuristics to detect bogus sense data from SAT layer.
  * smartd: Fixed crash on missing argument to '-s' directive.
    update-smart-drivedb: Now uses HTTPS for download by default.
  * update-smart-drivedb: New options to select URL and download tool.
  * update-smart-drivedb: New download tool 'svn'.
  * Drive database file now also includes the DEFAULT setting
    for each attribute.
  * HDD, SSD and USB additions to drive database.
  * Various code changes suggested by Clang Static Analyser and Cppcheck.
- enable "--with-nvme-devicescan" option
- update smartmontools-drivedb.h file
- use --with-savestates, --with-attributelog, --docdir instead of old options
* Thu Jan 14 2016 meissner@suse.com
- replaced keyring with 2015/2016 key.
  pub   rsa2048/0xDF0F1A49C4A4903A 2014-12-31 [expires: 2016-12-31]
    Key fingerprint = F41F 01FC 0784 4958 4FFC  CF57 DF0F 1A49 C4A4 903A
  uid   [ unkown] Smartmontools Signing Key (through 2016) <smartmontools-support@lists.sourceforge.net>
* Sun Jan 10 2016 p.drouand@gmail.com
- Update to version 6.0.4
  * Device type '-d usbprolific' for Prolific PL2571/277x USB bridges.
  * SAT: Support for ATA registers returned in fixed format sense data.
  * smartctl '-i' and '--identify': ATA ACS-4 and SATA 3.2 enhancements.
  * smartctl '-l xerror': Support for logs with more than 255 pages.
  * smartctl '-l devstat': Prints ACS-3 DSN flags.
  * smartctl '-l devstat': Read via SMART command if GP log is not
    available.
  * smartctl '-l scttempsts': Prints SCT SMART STATUS (ACS-4) and
    vendor specific SCT bytes.
  * HDD, SSD and USB additions to drive database.
  * Linux: AACRAID fixes, SMART STATUS should work now.
  * Linux: '/dev/megaraid_sas_ioctl_node' fd leak fix.
- Update smartmontools-drivedb.h to the latest version from the
  upstream branch RELEASE_6_4_DRIVEDB.
- Cleanup and remove conditional macros; the package doesn't build
  for SLE anyway
- Remove smartmontools-default-enabled.patch; not needed anymore
* Tue Mar 10 2015 sbrabec@suse.cz
- Run Self Tests:
  * Short Self Test every night
  * Extended Self Test every month
  * Discussion:
    http://lists.opensuse.org/opensuse-factory/2015-03/msg00040.html
- Dropped smartmontools-removable.patch
- Created smartmontools-suse-default.patch
* Mon Mar  9 2015 sbrabec@suse.cz
- Package empty /etc/smartd_warning.d for warning plugins.
- smartmontools-drivedb_h-update.sh: Fix default branch name.
- Comment fixes.
* Tue Mar  3 2015 sbrabec@suse.cz
- Improve drivedb.h update scriptlets: Detect update across
  branches.
- Check state of smartmontools-drivedb.h in %%prep.
- Add ghost records for files created by update-smart-drivedb.
- Improve smartmontools-drivedb_h-update.sh script: Perform spec
  file changess.
- Clean up on uninstall.
- Update smartmontools-drivedb.h to the latest version from the
  upstream branch RELEASE_6_3_DRIVEDB.
* Fri Nov 14 2014 dimstar@opensuse.org
- No longer perform gpg validation; osc source_validator does it
  implicit:
  + Drop gpg-offline BuildRequires.
  + No longer execute gpg_verify.
* Tue Oct  7 2014 sbrabec@suse.cz
- Re-add /usr/sbin/rcsmards symlink (bnc#900099).
- Fix service restart in smartmontools.generate_smartd_opts.in
  (bnc#900099).
* Wed Sep  3 2014 ro@suse.de
- re-add sysvinit support in specfile (fix build on sles11)
* Wed Sep  3 2014 ro@suse.de
- update to version 6.3
  - smartctl: Fixed bogus error messages from '-g/-s wcreorder'.
  - smartctl prints ATA form factor.
  - SCSI: Improved support of modern disks (SAS SSDs).
  - SCSI: Fixed sense data noise from old disks.
  - update-smart-drivedb man page.
  - configure option '--with-smartdscriptdir'.
  - configure option '--with-smartdplugindir'.
  - configure option '--with-systemdenvfile'.
  - configure option '--with-working-snprintf'.
  - Removed build time stamps to support reproducible builds.
  - Compile fixes for C++11.
  - HDD, SSD and USB additions to drive database.
  - Linux: Support for controllers behind AACRAID driver.
  - Linux: Fixed DEVICESCAN max path count.
  - FreeBSD: Fixed possible crash caused by wrong SCSI error handling.
  - FreeBSD: Compile fix for kFreeBSD.
  - Windows: Reworked CSMI port scanning.
  - QNX: Compile fix.
- dropped patches:
  smartmontools-nobuild-date.patch (code removed upstream)
* Mon May 26 2014 crrodriguez@opensuse.org
- Build with large file support in 32 bit systems.
* Thu Dec  5 2013 sbrabec@suse.com
- Add supplementary drivedb.h update script
  (smartmontools-drivedb_h-update.sh, bnc#851276).
- Skip drivedb.h verification by rpm -V (bnc#851276).
- Implement intelligent drivedb.h update not overwriting newer
  drivedb.h releases.
- Update smartmontools-drivedb.h to the latest version from the
  upstream branch trunk.
* Mon Jul 29 2013 sbrabec@suse.cz
- Update to version 6.2:
  * smartctl: Added ATA write cache reordering control using
    '-g wcreorder' and '-s wcreorder,[on|off]' options.
  * update-smart-drivedb: Updated for new SVN repository.
  * HDD, SSD and USB additions to drive database.
  * Areca RAID support: Fixed possible segfault on empty port.
  * HPT RAID support: Maximum disk number increased to 128.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Apr  3 2013 crrodriguez@opensuse.org
- remove all sysvinit support.
* Mon Mar 18 2013 sbrabec@suse.cz
- Update to version 6.1:
  * smartctl -l improved.
  * smartctl -s/-g wcache and rcache for SCSI devices.
  * smartctl prints more info for ATA and SCSI devices.
  * smartctl '--identify' updated for latest ATA ACS-3 spec.
  * smartd runs /etc/smartd_warning.sh to generate warning emails.
  * smartd '-w PATH' option to specify this executable.
  * smartd '-d ignore' directive.
  * smartd DEVICESCAN ignores devices already specified.
  * smartd: added support for -s and -A for SCSI devices.
  * smartd '-W' directive uses ATA attribute 190 if 194 is missing.
  * Support of larger SCSI defect lists via READ DEFECT(12).
  * Device type '-d usbjmicron,p' for Prolific USB bridges.
  * Many HDD, SSD and USB additions to drive database.
  * Support for SAS disks behind Areca controllers.
  * Improved support for SATA disks on LSI/Megaraid controllers.
  * Disks on MegaRaid controllers are automatically scanned.
- smartmontools.keyring: New signing key for the next 2 years.
* Wed Dec 12 2012 sbrabec@suse.cz
- Use sysconfig variables (sed on smartd.service.in) and generate
  smartd_opts for systemd smartd.service.
- Remove obsolete parsing of /etc/default/smartmontools
  (it is no more in upstream installation).
* Thu Nov 29 2012 sbrabec@suse.cz
- Verify GPG signature.
* Tue Nov 20 2012 sbrabec@suse.cz
- Re-introduce smartmontools-sysconfig.patch with
  SMARTD_SAVESTATES, SMARTD_ATTRLOG and SMARTD_EXTRA_OPTS sysconfig
  variables (bnc#790044).
* Thu Nov 15 2012 sbrabec@suse.cz
- Update to version 6.0 (bnc#789204):
  * option/directive '-F nologdir' and '-F xerrorlba'.
  * smartctl '--identify' option.
  * smartctl prints nominal media rotation rate (ATA).
  * smartctl prints SATA version and speed.
  * smartctl '-l sataphy' works for CD/DVD drives also.
  * smartctl '-x' includes ATA Device Statistics.
  * smartd warning emails include device identify info.
  * smartd '-d' output is flushed to support redirection.
  * Many HDD, SSD and USB additions to drive database.
  * smartctl options '-g, --get' and '-s, --set' to get/set various
    ATA settings: AAM, APM, Read look-ahead, Write cache, Security
    (freeze), Standby mode/timer.
  * smartd directive '-e' to set (most of) the above settings on
    startup.
  * smartctl options '-f hex' and '-f hex,[id|val]'.
  * smartctl does not start ATA self-test if another test is
    already running.  Override with new option '-t force'.
  * smartctl supports extended self-test polling times greater
    than 255 minutes.
  * Controller-independent SAT detection: '-d sat,auto[+TYPE]'.
  * smartd.conf DEFAULT directive.
  * Support for SATA disks behind Areca SAS RAID controllers and
    HP Smart Array controllers.
* Tue Nov  6 2012 coolo@suse.com
- do no longer require syslog on 12.3, journal is enough for
  some installations
* Tue Sep 11 2012 coolo@suse.com
- buildrequire systemd to have working rpm macros
* Thu May 31 2012 sweet_f_a@gmx.de
- update to the _latest_ smartmontools-5.42 tarball, see
  http://sourceforge.net/mailarchive/message.php?msg_id=28262364
  "The PKG_PROG_PKG_CONFIG macro was not expanded in configure"
- remove automake dependency
* Tue Feb 21 2012 sbrabec@suse.cz
- Disable PIE for SLE9.
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 22 2011 crrodriguez@opensuse.org
- When in a virtualized envirnment, hard disk monitoring
  with smartd is a task for the host, make systemd to skip
  the service if found running in such setup.
* Fri Oct 21 2011 sbrabec@suse.cz
- Upgrade to version 5.42 (bnc#725631):
  * smartctl option '-l devstat' (Device Statistics).
  * smartctl option '-l ssd' (SSD endurance indicator).
  * smartd logs identify information of each SCSI/SAS device.
  * smartd resends warning emails if problem reappears.
  * smartd directives '-l offlinests' and '-l selfteststs'.
  * Many HDD, SSD and USB additions to drive database.
  * Platform-specific man pages.
  * smartd.8 man page no longer includes smartd.conf.5.
  * Support for Areca controllers enhanced.
- Fixed pid file location (bnc#714647).
* Mon Oct 10 2011 bruno@ioda-net.ch
- reuse of %%makeinstall to build for SLES11_SP1-
* Sun Oct  9 2011 bruno@ioda-net.ch
- upgrade to 5.41 Date 2011-06-09
  - Failed self-tests outdated by a newer successful extended
    self-test are no longer reported as errors.
  - Support for ATA Long Logical/Physical Sectors (LLS/LPS).
  - 'smartctl --scan-open' can create a draft smartd.conf.
  - smartctl prints World Wide Name (WWN) of ATA device.
  - smartctl option '-f brief' to select new attribute output
    format which includes more flags and fits in 80 columns.
  - smartd logs identify information and WWN of each ATA device.
  - smartd logs warning from drive database if present.
  - smartd logs changes of offline data collection status.
  - smartd directive '-l scterc,READTIME,WRITETIME'.
  - smartd preserves last scheduled selective self-tests span.
  - 'smartd.service' file for systemd.
  - configure option '--with-systemdsystemunitdir'
  - configure option '--with-exampledir'.
  - configure searches for init.d or rc.d directory.
  - 'make install' does no longer overwrite an existing
    smartd.conf file.
  - 'update-smart-drivedb' does no longer require GNU sed.
  - Many HDD, SSD and USB additions to drive database.
  - Linux USB autodetection: Enable '-d sat,16' for newer kernels.
  - Linux megaraid: Fix segfault on non-data SCSI commands.
  - Linux megaraid: Fix pass-through of non-data ATA commands.
- clean up old patches included in upstream
- added systemd upstream configure option
- added patch for FSF-address
- clean up spec with spec-cleaner-
* Wed Jun  8 2011 sbrabec@suse.cz
- Added sysconfig options to set arbitrary smartd options and
  disable persistent state writes and attribute log (FATE#310460).
- Decrease log message on unsupported state writes to DEBUG
  (FATE#310460).
- Change sysconfig ServiceReload to ServiceRestart, otherwise
  sysconfig changes will not take effect until restart.
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Thu Feb  3 2011 pgajdos@suse.cz
- fixed smartctl -V command to show version [bnc#647521]
  * modified nobuild-date.patch
* Thu Jan 13 2011 sbrabec@suse.cz
- Removed support for SLE9 and older.
* Tue Dec  7 2010 coolo@novell.com
- prereq init script syslog
* Thu Oct 21 2010 ro@suse.de
- update to final 5.40
  - configure: '--enable-drivedb' is now the default.
  - Improved support for Intel SSDs.
  - Improved support for SandForce based SSDs.
  - Many additions to drive database.
  - smartctl option '-t vendor,N'.
  - Linux: Support SATA drives on LSI 3ware 9750 controllers.
  - Fix regression in smartd SMARTD_DEVICE and SMARTD_DEVICETYPE
    environment variables.
* Wed Oct  6 2010 sbrabec@suse.cz
- Added rpmlintrc.
- Removed Obsoletes for ancient packages.
- Enabled attribute log.
* Tue Sep 28 2010 cristian.rodriguez@opensuse.org
- Fix patch to remove build Dates
- Update to a newer version of 5.39.1 branch in order
  to support libcap-ng so smartd can drop privileges
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not include build enviroment infon in the binaries
  including date and time of compilation, makes build-compare
  happier.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Wed Feb 10 2010 sbrabec@suse.cz
- Updated to version 5.39.1:
  * Fix regression in smartctl option '-q, --quietmode'.
  * Fix regression in smartd directive '-l selftest'.
  * Linux: Allow smartd 'DEVICESCAN -d sat'.
  * Linux: Fix spin-up of SATA drive if '-n standby' is used
    (bnc#576662).
  * Support for up to 128 devices on 3ware controllers
  * smartctl option '-l xerror' to print ATA SMART Extended
    Comprehensive Error Log
  * Option '-d sat+TYPE' to use SAT with controllers which require
    '-d TYPE'
  * Option '-v ID,RAW_FORMAT,ATTR_NAME' to add new vendor specific
    attributes
  * Support for SSD drives using 64-bit raw attributes
  * Many additions to drive database
  * New simplified syntax for drive database
  * Configure option to add drive database file to distribution
  * smartd can now handle attributes 197 and 198 with increasing
    raw values
  * smartd logs changes of self-test execution status
  * smartd directive '-n powermode,N' to limit the number of
    skipped checks
  * smartd flag '!' for '-r' and '-R' directives to log changes as
    critical
  * Self-tests scheduled during system downtime or disk standby are
    run after next startup (bnc#469859).
  * smartd option '-s PREFIX' to store smartd internal state until
    next startup
  * smartd option '-A PREFIX' to log attributes at each check cycle
  * Configure options to enable the above by default
  * Change to an object oriented interface to access ATA and SCSI
    devices
  * Modules migrated to new interface
  * Rework of smartd data structures
  * Checkin date and SVN revision and optional BUILD_INFO printed
    in version info
  * SELinux fixes to 3ware device node creation
  * Use getaddrinfo() instead of gethostbyname() to support IPv6
  * Additional support for Samsung MLC flash drives
* Tue Feb  9 2010 sbrabec@suse.cz
- Changed daemon start policy from "force yes" to "default start"
  (bnc#567416).
* Mon Aug 10 2009 sbrabec@suse.cz
- Updated to the latest SVN snapshot:
  * More drives recognized: Fujitsu MHW2 BJ series, WD Caviar Black
    family, Western Digital AV-GP series, Transcend Solid-State
    Drive and Transcend Solid-State Drive V series, Seagate
    Momentus 5400.5 series.
  * Fix data type bug in checksum test for multi sector logs.
  * Add USB ID of Seagate FreeAgent Go.
  * Add experimental feature to log attribute values at each check
    cycle (ATA only).
  * Heads up about a non backwardly compatible change introduced in
    draft SAT-2 (sat2r8b.pdf) that will break our existing SAT
    processing code. Action needed if change stands.
  * smartctl: Don't report an attribute as failed if threshold is
    0.
  * Print only one warning on checksum errors in multi sector log.
  * Require to specify PORT parameter of '-d usbjmicron' if two
    disks are connected.
  * smartctl: Limit default number of printed entries for '-l
    xerror' to 8, for '-l xselftest' to 25.
  * smartctl: Fix number of entries in '-l xselftest' output.
  * Add USB IDs of a SunplusIT bridge, three WD drives, and an
    unsupported Iomega drive.
  * smartd: Add '!' flag to '-r' and '-R' directives. If specified,
    message is logged as LOG_CRIT and warning mail is sent if
    attribute normalized or raw value changes.
  * Add names for some attributes used in Samsung MLC drives:
    178-180 & 183
  * smartctl: Add option '-x, --xall' to print all info including
    extended SMART logs and non-SMART info.
  * smartctl: Add '-l xerror,error' and '-l xselftest,selftest' to
    print the old logs if the extended logs are not supported.
  * Disable 48-bit ATA commands for JMicron USB bridges by default.
  * smartd: Don't ignore the '-n' directive when a self-test is
    scheduled.
  * SCSI (SAS): implement '-l sasphy,reset'.
  * SCSI (SAS): add '-l sasphy' and '-l sasphy,reset' into smartctl.
  * Print General Purpose Logs even if GPL feature bit is missing.
* Sat Jul 18 2009 dominique-obs@leuenberger.net
- bootstrap with automake-1.11
* Wed Jun  3 2009 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * SCSI: Fetch load-unload cycle counts
  * smartd: Fix '-M test' directive in conjunction with '-s'
  * knowndrives updates
  * Add '+' modifier to smartd '-C' and '-U' directives
  * Add experimental option '-d usbsunplus' for drives behind
    SunplusIT USB bridges.
  * Add smartctl '-d test' option
  * Add experimental USB device type autodetection
  * Add new SMART STATUS check command for JMicron USB bridges
  * Add smartctl option '-l xerror[,NUM]'
  * Accept half healthy (and half unhealthy) indication from the
    SMART RETURN STATUS.
  * Workaround for huge raw values of Reallocated_Sector_Ct and
    Reallocated_Event_Ct for newer Fujitsu disks.
* Wed Feb 11 2009 sbrabec@suse.cz
- Enabled selinux support only for supported platforms.
- Removed support for SLE9 (no more compilable).
* Thu Nov 27 2008 sbrabec@suse.cz
- smartd_opts migrated to sysconfig (bnc#448205).
* Fri Oct 24 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * DEVICESCAN works again with SATA (bnc#436567)
  * knowndrives updates, now using full regexps
  * support for local drive database entries from optional file
  * support for scheduled self tests
  * smartd persistent state and delayed test scheduling support
  * support for disks behind MegaRAID controllers
  * Improve min/max temperature recording in conjunction with '-s'.
  * new options to -l
  * code cleanup and other fixes
- Init script updated to support "unused" state (bnc#436567).
- Added "rescan" to the init script to force rescanning of devices.
- Enabled selinux support to create /dev/tw[ae] with correct
  contexts.
* Tue Sep  2 2008 sbrabec@suse.cz
- Desktop neutral powersave-notify is no longer available.
  Use "wall" to report expected disc failures.
* Mon Aug 18 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * Areca device support.
  * More discs recognized.
  * Code improvements to simplify adding new platforms and devices.
* Fri May 23 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * USB Cypress device support in smartd (bnc#387094).
- Fixed help strings regarding the USB Cypress support.
- Do not report errors after disconnecting of removable discs
  (bnc#308557).
* Tue May  6 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot (bnc#387094):
  * USB Cypress device support.
  * 3ware support improvements.
* Mon Mar 10 2008 sbrabec@suse.cz
- Updated to version 5.38:
  * smartd.initd.in addition
  * On Linux, DEVICESCAN now automatically recognizes SATA devices
    behind libata, and SATA devices behind the Marvell driver.
  * On Linux, a '-d sat' or '-d marvell' is automatically added
    if libata or the marvell driver are recognized behind a SCSI
    device type
  * SAT device type + SCSI generic devices work properly with
    smartd under Linux
  * Many additions to drive database
  * Some ATA-8 updates
  * Dragonfly support
  * Fixed some ATA identity byte swap problems on big endian CPUs
  * No-fork option added to smartd
  * 3ware support for controllers with more disks (32 max)
  * Improved SMART Attribute list and descriptions
  * Fix to smartctl return codes
  * Fix to scheduled tests on Highpoint RAID controllers
  * New samsung firmware bug workaround option
  * Auto-offline and Auto-save fixed in Linux + libata
  * Solaris: better SCSI support
  * Fixed and improvements to CCISS support
  * More options for SCSI temperature monitoring and history
  * Additional command line options for selective self-tests
  * Compilation fixes for various platforms.
* Tue Oct  9 2007 sbrabec@suse.cz
- Updated to the CVS version (#326738):
  * Supports SAS discs behind CCISS RAID.
- Removed bogus patch breaking HighPoint RAID (#225639).
* Wed Aug 22 2007 sbrabec@suse.cz
- Worked around missing %%restart_on_update in older versions.
- Build correctly in older SuSE versions.
* Tue Jul 24 2007 sbrabec@suse.cz
- Updated to version 5.37:
  * Rely on general SAT code instead of Linux specific.
  * Increased max line length 128 to 256 characters.
  * Added new items into drive database.
  * Fixed inclusion of PRI?64 macros from inttypes.h.
  * Fix selective self test log revision number.
  * Compile fix for SuSE.
- Really start smartd by default on new enough kernels (#201715).
- Fixed behavior for SATA discs (#225639).
* Mon Mar  5 2007 pgajdos@suse.cz
- fixed 'array subscript is above array bounds' (#239956)
* Mon Jan 22 2007 ssommer@suse.de
- fix build for automake-0.9b
* Thu Jan 18 2007 ssommer@suse.de
- support building with automake-1.10
* Wed Oct 25 2006 sbrabec@suse.cz
- Updated to the today CVS version:
  * Supports SATA devices scanning out of the box (#201715#c9).
  * Supports SATA devices behind SCSI ATA Translation layer.
  * Supports SATA drives behind HighPoint Raid controllers.
  * Supports HP SmartArray RAID controller (cciss) (#186013).
- Updated SATA support stuff.
- Start smartd by default on new enough kernels (#201715).
* Wed Sep 13 2006 sbrabec@suse.cz
- Integrated with powersave.
- Use upstream init script.
* Thu Sep  7 2006 sbrabec@suse.cz
- Updated to version 5.36:
  * Additions to the table of known drives.
  * Works 'out of the box' with Linux SATA libata.
  * smartd option added to list test schedules.
  * smartctl option added to list part of drive database.
  * Various improvements for SCSI disks and logs.
  * Printing of drive family info.
  * SCSI disks: output size of grown defect list.
  * Added info about drive family to 'smartctl -i' output.
  * Added option ',q' for smartd '-n' directive to suppress
    'skipping checks' message which may spin up laptop disk.
  * Added message if smartd '-n' check power mode spins up disk.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun 20 2005 ro@suse.de
- use RPM_OPT_FLAGS
- build with fPIE/pie
* Fri Mar 18 2005 sbrabec@suse.cz
- Additional information on SATA support.
* Tue Feb 22 2005 sbrabec@suse.cz
- Added comments on temperature data in smartd.conf (#50156).
* Mon Jan 24 2005 sbrabec@suse.cz
- Updated to version 5.33.
* Mon Jan  3 2005 sbrabec@suse.cz
- Fixed missing pid reference in init script (#49546).
- Updated README.SATA.
* Fri Aug 27 2004 sbrabec@suse.cz
- Updated to version 5.32.
* Sun Jun  6 2004 lmuelle@suse.de
- Update to version 5.31.
- Add stop_on_removal to preun and restart_on_update to postun.
* Sun Apr 25 2004 lmuelle@suse.de
- Add reload and condrestart to init script; [#39425].
* Mon Mar  8 2004 sbrabec@suse.cz
- Updated to version 5.30.
* Fri Mar  5 2004 sbrabec@suse.cz
- Added README.SATA.
- Added %%build section.
* Tue Mar  2 2004 sbrabec@suse.cz
- Updated to version 5.29.
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 mmj@suse.de
- Updated to version 5.26
* Fri Aug 22 2003 sbrabec@suse.cz
- Updated to version 5.1-18.
* Thu Aug 21 2003 sbrabec@suse.cz
- Updated to version 5.1-17.
* Mon Aug 11 2003 sbrabec@suse.cz
- Added $sendmail to X-UnitedLinux-Should-Start.
* Thu Aug  7 2003 sbrabec@suse.cz
- Updated to version 5.1.16.
* Wed May 21 2003 sbrabec@suse.cz
- Updated to version 5.1.9.
- Fixed RPM file attributes.
* Wed Mar 26 2003 sbrabec@suse.cz
- Updated to version 5.1.9.
* Mon Jan 27 2003 sbrabec@suse.cz
- Updated to version 5.1.4.
* Mon Jan 13 2003 sbrabec@suse.cz
- Updated to version 5.1.1.
* Tue Dec 10 2002 sbrabec@suse.cz
- Updated to version 5.0.49.
* Mon Nov 25 2002 sbrabec@suse.cz
- Fixed SuSE specific things in docs and manual pages.
* Mon Nov 18 2002 sbrabec@suse.cz
- New package.
